.. _community-call-notes:

====================
Community Call Notes
====================

The Jupyter Community Call is an open video call. Think of this as a "monthly, virtual JupyterCon". It's a place for *anyone* to announce and share fun things happening in the Jupyter community. Everyone is welcome (even if you're not presenting). We record these videos and post them on YouTube. For more information, `read this discourse thread <https://discourse.jupyter.org/t/all-jupyter-community-calls/668>`__.

.. toctree::
   :maxdepth: 1

   December 2023 <2023-december.md>
   February 2023 <2023-february.md>
   January 2023 <2023-january.md>
   November 2022 <2022-november.md>
   October 2022 <2022-october.md>
   September 2022 <2022-september.md>
   August 2022 <2022-august.md>
   July 2022 <2022-july.md>
   June 2022 <2022-june.md>
   May 2022 <2022-may.md>
   April 2022 <2022-april.md>
   March 2022 <2022-march.md>
   February 2022 <2022-february.md>
   January 2022 <2022-january.md>
   November 2021 <2021-november.md>
   October 2021 <2021-october.md>
   September 2021 <2021-september.md>
   August 2021 <2021-august.md>
   July 2021 <2021-july.md>
   June 2021 <2021-june.md>
   May 2021 <2021-may.md>
   April 2021 <2021-april.md>
   March 2021 <2021-march.md>
   February 2021 <2021-february.md>
   January 2021 <2021-january.md>
   December 2020 <2020-december.md>
   November 2020 <2020-november.md>
   September 2019 <2019-september.md>
   August 2019 <2019-august.md>
   June 2019 <2019-june.md>
   May 2019 <2019-may.md>
   April 2019 <2019-april.md>
   March 2019 <2019-march.md>
